<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AboutPreferences</name>
    <message>
        <location filename="../src/ui/qml/AboutPreferences.qml" line="14"/>
        <source>Ricochet %1</source>
        <extracomment>%1 version, e.g. 1.0.0</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddContactDialog</name>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="51"/>
        <source>Share your Ricochet ID to allow connection requests</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="107"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="112"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactActions</name>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="40"/>
        <source>Open Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="44"/>
        <source>Details...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="48"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="53"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactIDField</name>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="41"/>
        <source>&lt;b&gt;%1&lt;/b&gt; is already your contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="43"/>
        <source>You can&apos;t add yourself as a contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="45"/>
        <source>Enter an ID starting with &lt;b&gt;ricochet:&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="81"/>
        <source>Copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="93"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactList</name>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="76"/>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="77"/>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="78"/>
        <source>Requests</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="79"/>
        <source>Rejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="80"/>
        <source>Outdated</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactPreferences</name>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="98"/>
        <source>Date added:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="106"/>
        <source>Last seen:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="116"/>
        <source>Request:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="126"/>
        <source>Pending connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="127"/>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="128"/>
        <source>Accepted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="129"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="130"/>
        <source>Rejected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="134"/>
        <source>%1 (Connected)</source>
        <extracomment>%1 status, e.g. &quot;Accepted&quot;</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="140"/>
        <source>Response:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="163"/>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="170"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactRequestDialog</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="55"/>
        <source>Someone new is asking to connect to you</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="102"/>
        <source>Reject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="107"/>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactRequestFields</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="17"/>
        <source>ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="29"/>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="40"/>
        <source>Message:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GeneralPreferences</name>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="13"/>
        <source>Use a single window for conversations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="21"/>
        <source>Open links in default browser without prompting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="29"/>
        <source>Play audio notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="38"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="53"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="76"/>
        <source>Restart Ricochet to apply changes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguagesModel</name>
    <message>
        <location filename="../src/ui/LanguagesModel.cpp" line="43"/>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Ricochet Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="19"/>
        <source>Add Contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="28"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="75"/>
        <source>Click to add contacts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="191"/>
        <source>Remove %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="192"/>
        <source>Do you want to permanently remove %1?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageDelegate</name>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="26"/>
        <source>%1 is offline</source>
        <extracomment>%1 nickname</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="140"/>
        <source>Open with Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="154"/>
        <source>Add as Contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="166"/>
        <source>Copy Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="173"/>
        <source>Copy Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageDialogWrapper</name>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="8"/>
        <source>Remove %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="10"/>
        <source>Do you want to permanently remove %1?</source>
        <extracomment>%1 nickname</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="11"/>
        <source>This contact will no longer be able to message you, and will be notified about the removal. They may choose to send a new connection request.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkSetupWizard</name>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="100"/>
        <source>This computer&apos;s Internet connection is free of obstacles. I would like to connect directly to the Tor network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="107"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="124"/>
        <source>This computer&apos;s Internet connection is censored, filtered, or proxied. I need to configure network settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="131"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OfflineStateItem</name>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="107"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="115"/>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="143"/>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="169"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenBrowserDialog</name>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="40"/>
        <source>&lt;b&gt;Warning!&lt;/b&gt; Opening links with your default browser will harm your security and anonymity.&lt;br&gt;&lt;br&gt;You can &lt;a href=&apos;.&apos;&gt;copy to the clipboard&lt;/a&gt; instead.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="59"/>
        <source>Don&apos;t ask again for links from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="65"/>
        <source>Don&apos;t ask again for any links (not recommended!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="72"/>
        <source>Open Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="84"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="12"/>
        <source>Ricochet Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="41"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
        <source>Tor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCocoaMenuItem</name>
    <message>
        <location filename="../src/ui/qml/MainWindow.qml" line="29"/>
        <source>Preference</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StartupStatusPage</name>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="18"/>
        <source>The Tor process was not started successfully. This is most likely an installation or system error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="49"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TorBootstrapStatus</name>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="17"/>
        <source>Connecting to the Tor network…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="51"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Hide details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Show details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="70"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TorConfigurationPage</name>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="73"/>
        <source>Does this computer need a proxy to access the internet?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="85"/>
        <source>Proxy type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="90"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="92"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="107"/>
        <source>Address:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="116"/>
        <source>IP address or hostname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="119"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="130"/>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="140"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="150"/>
        <source>Optional</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="143"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="160"/>
        <source>Does this computer&apos;s Internet connection go through a firewall that only allows connections to certain ports?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="171"/>
        <source>Allowed ports:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="178"/>
        <source>Example: 80,443</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="189"/>
        <source>If this computer&apos;s Internet connection is censored, you will need to obtain and use bridge relays.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="198"/>
        <source>Enter one or more bridge relays (one per line):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="213"/>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="220"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TorPreferences</name>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="25"/>
        <source>Running:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <source>External</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="27"/>
        <source>Control connected:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="29"/>
        <source>Circuits established:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="31"/>
        <source>Hidden service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Offline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="33"/>
        <source>Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="60"/>
        <source>Error: &lt;b&gt;%1&lt;/b&gt;</source>
        <extracomment>%1 is error message</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="76"/>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TorStateWidget</name>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="9"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="20"/>
        <source>Connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="12"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="22"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="25"/>
        <source>Connecting… (%1%)</source>
        <extracomment>%1 is progress percentage, e.g. 100</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="32"/>
        <source>Online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="34"/>
        <source>Connected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
